<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="134"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="135"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="137"/>
        <source>Lightweight file manager</source>
        <translation>Lekki menedżer plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="143"/>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="139"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>Programowanie:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="138"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="142"/>
        <source>Authors</source>
        <translation>Autorzy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_about.h" line="160"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="110"/>
        <source>Removable medium is inserted</source>
        <translation>Wykryto nośnik wymienny</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="112"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;Wykryto nośnik wymienny&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="113"/>
        <source>Type of medium:</source>
        <translation>Typ nośnika:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="114"/>
        <source>Detecting...</source>
        <translation>Wykrywanie...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_autorun.h" line="115"/>
        <source>Please select the action you want to perform:</source>
        <translation>Wybierz działanie, które chcesz wykonać:</translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="75"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="76"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="77"/>
        <source>Desktop folder:</source>
        <translation>Katalog Pulpitu:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="79"/>
        <source>Image file</source>
        <translation>Plik obrazka</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="84"/>
        <source>Folder path</source>
        <translation>Ścieżka katalogu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-folder.h" line="85"/>
        <source>&amp;Browse</source>
        <translation>&amp;Wybierz</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="254"/>
        <source>Desktop Preferences</source>
        <translation>Ustawienia pulpitu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="255"/>
        <source>Background</source>
        <translation>Tło</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="256"/>
        <source>Wallpaper mode:</source>
        <translation>Tryb:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="257"/>
        <source>Wallpaper image file:</source>
        <translation>Obraz tła:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="259"/>
        <source>Select background color:</source>
        <translation>Kolor tła:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="261"/>
        <source>Image file</source>
        <translation>Plik obrazka</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="266"/>
        <source>Image file path</source>
        <translation>Ścieżka obrazka</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="267"/>
        <source>&amp;Browse</source>
        <translation>&amp;Wybierz</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="268"/>
        <source>Label Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="271"/>
        <source>Select  text color:</source>
        <translation>Kolor tekstu:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="272"/>
        <source>Select shadow color:</source>
        <translation>Kolor cienia:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="273"/>
        <source>Select font:</source>
        <translation>Czcionka:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="275"/>
        <source>General</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="276"/>
        <source>Window Manager</source>
        <translation>Menedżer Okien</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="277"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>Wyświetlanie menu menedżera okien po kliknięciu na pulpicie</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">Pulpit</translation>
    </message>
    <message>
        <source>Desktop folder:</source>
        <translation type="vanished">Katalog Pulpitu:</translation>
    </message>
    <message>
        <source>Folder path</source>
        <translation type="vanished">Ścieżka katalogu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_desktop-preferences.h" line="278"/>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
</context>
<context>
    <name>FindFilesDialog</name>
    <message>
        <source>Find Files</source>
        <translation type="vanished">Znajdź pliki</translation>
    </message>
    <message>
        <source>Name/Location</source>
        <translation type="vanished">Nazwa/Lokalizacja</translation>
    </message>
    <message>
        <source>File name patterns</source>
        <translation type="vanished">Wzorce nazwy pliku</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Wzorzec:</translation>
    </message>
    <message>
        <source>Case insensitive</source>
        <translation type="vanished">Ignoruj wielkość liter</translation>
    </message>
    <message>
        <source>Use regular expression</source>
        <translation type="vanished">Użyj wyrażeń regularnych</translation>
    </message>
    <message>
        <source>Places to search</source>
        <translation type="vanished">Szukaj w</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Usuń</translation>
    </message>
    <message>
        <source>Search in sub directories</source>
        <translation type="vanished">Szukaj w podkatalogach</translation>
    </message>
    <message>
        <source>Search hidden files</source>
        <translation type="vanished">Szukaj wśród ukrytych plików</translation>
    </message>
    <message>
        <source>File Type</source>
        <translation type="vanished">Typ pliku</translation>
    </message>
    <message>
        <source>Only search for files of following types:</source>
        <translation type="vanished">Szukaj tylko plików o podanym typie:</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation type="vanished">Pliki tekstowe</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation type="vanished">Obrazy</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation type="vanished">Pliki dźwiękowe</translation>
    </message>
    <message>
        <source>Video files</source>
        <translation type="vanished">Pliki wideo</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="vanished">Dokumenty</translation>
    </message>
    <message>
        <source>Content</source>
        <translation type="vanished">Zawartość</translation>
    </message>
    <message>
        <source>File contains</source>
        <translation type="vanished">Pliki zawierające</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="vanished">Ustawienia</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="vanished">Rozmiar pliku</translation>
    </message>
    <message>
        <source>Bigger than:</source>
        <translation type="vanished">Większy niż:</translation>
    </message>
    <message>
        <source>Smaller than:</source>
        <translation type="vanished">Mniejszy niż:</translation>
    </message>
    <message>
        <source>Last Modified Time</source>
        <translation type="vanished">Czas ostatniej modyfikacji</translation>
    </message>
    <message>
        <source>Earlier than:</source>
        <translation type="vanished">Wcześniejszy niż:</translation>
    </message>
    <message>
        <source>Later than:</source>
        <translation type="vanished">Późniejszy niż:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="557"/>
        <source>File Manager</source>
        <translation>Menedżer plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="560"/>
        <source>Go Up</source>
        <translation>Katalog nadrzędny</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="562"/>
        <source>Alt+Up</source>
        <translation>Alt+Góra</translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="vanished">Katalog użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="564"/>
        <source>Alt+Home</source>
        <translation>Alt+Home</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="583"/>
        <source>Reload</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="566"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="563"/>
        <source>&amp;Home</source>
        <translation>Katalog &amp;użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="565"/>
        <source>&amp;Reload</source>
        <translation>&amp;Odśwież</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="567"/>
        <source>Go</source>
        <translation>Przejdź</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="568"/>
        <source>Quit</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="569"/>
        <source>&amp;About</source>
        <translation>&amp;O programie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="572"/>
        <source>New Window</source>
        <translation>Nowe okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="574"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="575"/>
        <source>Show &amp;Hidden</source>
        <translation>Wyświetl &amp;ukryte pliki</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="576"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="577"/>
        <source>&amp;Computer</source>
        <translation>&amp;Komputer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="578"/>
        <source>&amp;Trash</source>
        <translation>Ko&amp;sz</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="579"/>
        <source>&amp;Network</source>
        <translation>&amp;Sieć</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="580"/>
        <source>&amp;Desktop</source>
        <translation>&amp;Pulpit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="581"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>&amp;Dodaj zakładkę</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="582"/>
        <source>&amp;Applications</source>
        <translation>P&amp;rogramy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="589"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="590"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiuj</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="591"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="592"/>
        <source>&amp;Paste</source>
        <translation>&amp;Wklej</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="593"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="594"/>
        <source>Select &amp;All</source>
        <translation>Zazn&amp;acz wszystko </translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="596"/>
        <source>Pr&amp;eferences</source>
        <translation>Pr&amp;eferencje</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="597"/>
        <source>&amp;Ascending</source>
        <translation>&amp;Rosnąco</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="598"/>
        <source>&amp;Descending</source>
        <translation>&amp;Malejąco</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="599"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Nazwa</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="600"/>
        <source>By &amp;Modification Time</source>
        <translation>Data &amp;modyfikacji</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="601"/>
        <source>By File &amp;Type</source>
        <translation>&amp;Typ pliku</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="602"/>
        <source>By &amp;Owner</source>
        <translation>W&amp;łaściciel</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="603"/>
        <source>&amp;Folder First</source>
        <translation>Najpierw &amp;katalogi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Odwróć zaznaczenie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="620"/>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="622"/>
        <source>&amp;Rename</source>
        <translation>&amp;Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="629"/>
        <source>&amp;Case Sensitive</source>
        <translation>Uwzględniaj wielkość &amp;liter</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="630"/>
        <source>By File &amp;Size</source>
        <translation>Według &amp;rozmiaru</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="631"/>
        <source>&amp;Close Window</source>
        <translation>&amp;Zamknij okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="595"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="558"/>
        <source>Go &amp;Up</source>
        <translation>Do &amp;góry</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="570"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nowe okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="584"/>
        <source>&amp;Icon View</source>
        <translation>&amp;Ikony</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="585"/>
        <source>&amp;Compact View</source>
        <translation>Lista &amp;zwarta</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="586"/>
        <source>&amp;Detailed List</source>
        <translation>Lista &amp;szczegółowa</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="587"/>
        <source>&amp;Thumbnail View</source>
        <translation>&amp;Miniatury</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="588"/>
        <source>Cu&amp;t</source>
        <translation>W&amp;ytnij</translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="vanished">Rosnąco</translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="vanished">Malejąco</translation>
    </message>
    <message>
        <source>By File Name</source>
        <translation type="vanished">Według nazwy</translation>
    </message>
    <message>
        <source>By Modification Time</source>
        <translation type="vanished">Według czasu modyfikacji</translation>
    </message>
    <message>
        <source>By File Type</source>
        <translation type="vanished">Według typu</translation>
    </message>
    <message>
        <source>By Owner</source>
        <translation type="vanished">Według właściciela</translation>
    </message>
    <message>
        <source>Folder First</source>
        <translation type="vanished">Najpierw katalogi</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="604"/>
        <source>New &amp;Tab</source>
        <translation>Nowa &amp;karta</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="606"/>
        <source>New Tab</source>
        <translation>Nowa karta</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="608"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="609"/>
        <source>Go &amp;Back</source>
        <translation>&amp;Poprzedni katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="611"/>
        <source>Go Back</source>
        <translation>Poprzedni katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="613"/>
        <source>Alt+Left</source>
        <translation>Alt+Lewo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="614"/>
        <source>Go &amp;Forward</source>
        <translation>&amp;Następny katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="616"/>
        <source>Go Forward</source>
        <translation>Następny katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="618"/>
        <source>Alt+Right</source>
        <translation>Alt+Prawo</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="621"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="623"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="624"/>
        <source>C&amp;lose Tab</source>
        <translation>&amp;Zamknij kartę</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="626"/>
        <source>File &amp;Properties</source>
        <translation>Właściwości &amp;pliku</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="628"/>
        <source>&amp;Folder Properties</source>
        <translation>Właściwości &amp;katalogu</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="vanished">Katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="638"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Blank File</source>
        <translation type="vanished">Pusty plik</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="640"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="646"/>
        <source>C&amp;reate New</source>
        <translation>&amp;Nowy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="649"/>
        <source>&amp;Sorting</source>
        <translation>&amp;Uszereguj według</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="654"/>
        <source>Main Toolbar</source>
        <translation>Pasek narzędziowy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="625"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="627"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation type="vanished">Uwzględniaj wielkość liter</translation>
    </message>
    <message>
        <source>By File Size</source>
        <translation type="vanished">Według rozmiaru</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="vanished">Zamknij okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="632"/>
        <source>Edit Bookmarks</source>
        <translation>Edytuj zakładki</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="633"/>
        <source>Open &amp;Terminal</source>
        <translation>Otwórz w &amp;terminalu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="634"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="635"/>
        <source>Open as &amp;Root</source>
        <translation>Otwórz jako &amp;Root</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="636"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>Edytuj &amp;Zakładki</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="637"/>
        <source>&amp;Folder</source>
        <translation>&amp;Katalog</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="639"/>
        <source>&amp;Blank File</source>
        <translation>&amp;Pusty plik</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="641"/>
        <source>&amp;Find Files</source>
        <translation>&amp;Znajdź pliki</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="642"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="643"/>
        <source>Filter</source>
        <translation>Filtruj</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="644"/>
        <source>Filter by string...</source>
        <translation>Wpisz część nazwy pliku...</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="645"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="647"/>
        <source>&amp;Help</source>
        <translation>Po&amp;moc</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="648"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="650"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="651"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Zakładki</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="652"/>
        <source>&amp;Go</source>
        <translation>P&amp;rzejdź</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_main-win.h" line="653"/>
        <source>&amp;Tool</source>
        <translation>&amp;Narzędzia</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>Name of configuration profile</source>
        <translation>Nazwa profilu konfiguracji</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="162"/>
        <source>PROFILE</source>
        <translation>PROFIL</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="165"/>
        <source>Run PCManFM as a daemon</source>
        <translation>Uruchom PCManFM jako daemon</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="168"/>
        <source>Quit PCManFM</source>
        <translation>Zakończ PCManFM</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="171"/>
        <source>Launch desktop manager</source>
        <translation>Uruchom menedżera pulpitu</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="174"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>Wyłądż menedżera pulpitu jeżeli jest uruchomiony</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="177"/>
        <location filename="../application.cpp" line="193"/>
        <source>NAME</source>
        <translation>NAZWA</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="180"/>
        <source>Open new window</source>
        <translation>Otwórz nowe okno</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="183"/>
        <source>Open Find Files utility</source>
        <translation>Otwórz narzędzie wyszukiwania</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>Ustaw tło pulpitu z obrazka PLIK</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="186"/>
        <source>FILE</source>
        <translation>PLIK</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)</source>
        <translation>Ustaw tryb tapety pulpitu. TRYB=(color|stretch|fit|center|tile)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="190"/>
        <source>MODE</source>
        <translation>TRYB</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="193"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>Files or directories to open</source>
        <translation>Pliki lub katalogi do otwarcia</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="196"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[PLIK1, PLIK2,...]</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="500"/>
        <location filename="../application.cpp" line="507"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="507"/>
        <source>Terminal emulator is not set.</source>
        <translation>Nie ustawiono emulatora terminala.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../autorundialog.cpp" line="43"/>
        <source>Open in file manager</source>
        <translation>Otwórz w menedżerze plików</translation>
    </message>
    <message>
        <location filename="../autorundialog.cpp" line="133"/>
        <source>Removable Disk</source>
        <translation>Nośnik wymienny</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="50"/>
        <source>Fill with background color only</source>
        <translation>Wypełnij tylko kolorem</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="51"/>
        <source>Stretch to fill the entire screen</source>
        <translation>Rozciągnij do rozmiaru ekranu</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="52"/>
        <source>Stretch to fit the screen</source>
        <translation>Dopasuj do rozmiaru ekranu</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="53"/>
        <source>Center on the screen</source>
        <translation>Wyśrodkuj</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="54"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>Sąsiadująco</translation>
    </message>
    <message>
        <location filename="../desktoppreferencesdialog.cpp" line="157"/>
        <source>Image Files</source>
        <translation>Pliki obrazków</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../desktopwindow.cpp" line="366"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>Przyp&amp;nij do aktualnej pozycji</translation>
    </message>
    <message>
        <location filename="../desktopwindow.cpp" line="388"/>
        <source>Desktop Preferences</source>
        <translation>Ustawienia pulpitu</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Usuń tekst (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>Version: %1</source>
        <translation>Wersja: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Przenieś do kosza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>&amp;Delete</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Switch user command is not set.</source>
        <translation>Nie ustawiono polecenia do przełączania użytkowników.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="190"/>
        <source>Icon View</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="191"/>
        <source>Compact Icon View</source>
        <translation>Lista zwarta</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="192"/>
        <source>Thumbnail View</source>
        <translation>Miniatury</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="193"/>
        <source>Detailed List View</source>
        <translation>Lista szczegółowa</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../tabpage.cpp" line="248"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="261"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>Wolna przestrzeń: %1 (całkowita: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="276"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n elementów</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../tabpage.cpp" line="278"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform>(%n ukrytych)</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../tabpage.cpp" line="426"/>
        <source>%1 item(s) selected</source>
        <translation>Zaznaczono %1 elementy</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../view.cpp" line="103"/>
        <source>Open in New T&amp;ab</source>
        <translation>Otwórz w nowej &amp;karcie</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="107"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Otwórz w nowym &amp;oknie</translation>
    </message>
    <message>
        <location filename="../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>Otwórz w &amp;terminalu</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="706"/>
        <source>Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="715"/>
        <source>User Interface</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="711"/>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="717"/>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="779"/>
        <source>Thumbnail</source>
        <translation>Miniatury</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="719"/>
        <source>Volume</source>
        <translation>Wolumen</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="721"/>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="742"/>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="744"/>
        <source>Size of big icons:</source>
        <translation>Rozmiar dużych ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="745"/>
        <source>Size of small icons:</source>
        <translation>Rozmiar małych ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="746"/>
        <source>Size of thumbnails:</source>
        <translation>Rozmiar miniatur:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="747"/>
        <source>Size of side pane icons:</source>
        <translation>Rozmiar ikon panelu bocznego:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="743"/>
        <source>Icon theme:</source>
        <translation>Motyw ikon:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="753"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="757"/>
        <source>Default width of new windows:</source>
        <translation>Domyślna szerokość nowych okien:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="758"/>
        <source>Default height of new windows:</source>
        <translation>Domyślna wysokość nowych okien:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="754"/>
        <source>Always show the tab bar</source>
        <translation>Zawsze pokazuj pasek kart</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="755"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>Pokaż przycisk &apos;Zamknij&apos; na kartach</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="756"/>
        <source>Remember the size of the last closed window</source>
        <translation>Pamiętaj rozmiar ostatnio zamkniętego okna</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="724"/>
        <source>Browsing</source>
        <translation>Przeglądanie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="725"/>
        <source>Open files with single click</source>
        <translation>Otwórz pliki pojedynczym kliknięciem</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="726"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>Opóźnienie zaznaczania (0 aby wyłączyć)</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="727"/>
        <source>Default view mode:</source>
        <translation>Domyślny tryb widoku:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="728"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="736"/>
        <source>File Operations</source>
        <translation>Operacje na plikach</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="737"/>
        <source>Confirm before deleting files</source>
        <translation>Potwierdź przed usunięciem plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="738"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>Przenoszenie plików do &quot;Kosza&quot; zamiast usuwania z dysku</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="783"/>
        <source>Show thumbnails of files</source>
        <translation>Wyświetl miniatury zawartości plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="782"/>
        <source>Only show thumbnails for local files</source>
        <translation>Wyświetl miniatury zawartości tylko lokalnych plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="713"/>
        <source>Display</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="729"/>
        <source>Bookmarks:</source>
        <translation>Zakładki:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="732"/>
        <source>Open in current tab</source>
        <translation>Otwórz w aktualnej zakładce</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="733"/>
        <source>Open in new tab</source>
        <translation>Otwórz w nowej zakładce</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="734"/>
        <source>Open in new window</source>
        <translation>Otwórz w nowym oknie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="739"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>Usuwaj pliki na urządzeniach wymiennych zamiast przenosić je do kosza</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="740"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>Potwierdź przed przeniesieniem plików do &quot;Kosza&quot;</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="741"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>Nie pytaj o parametry przy uruchamianiu plików wykonywalnych</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="748"/>
        <source>User interface</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="750"/>
        <source>Treat backup files as hidden</source>
        <translation>Traktuj pliki kopii zapasowych jako ukryte</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="751"/>
        <source>Always show full file names</source>
        <translation>Zawsze wyświetlaj pełne nazwy plików</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="752"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>Przytłumione ikony dla plików ukrytych</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="759"/>
        <source>Show in places</source>
        <translation>Pokaż w położeniach</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="764"/>
        <source>Home</source>
        <translation>Katalog użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="766"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="768"/>
        <source>Trash can</source>
        <translation>Kosz</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="770"/>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="772"/>
        <source>Applications</source>
        <translation>Aplikacje</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="774"/>
        <source>Devices</source>
        <translation>Urządzenia</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="776"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="780"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>Nie generuj miniatur dla plików większych niż:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="781"/>
        <source> KB</source>
        <translation> KB</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="784"/>
        <source>Auto Mount</source>
        <translation>Automatyczne montowanie</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="785"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>Montowanie wolumenów podczas uruchamiania programu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="786"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>Montowanie nośników wymiennych po wsunięciu</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="787"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>Wyświetlanie możliwych czynności po wsunięciu nośnika wymiennego</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="788"/>
        <source>When removable medium unmounted:</source>
        <translation>Działania po odmontowaniu nośnika wymiennego:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="789"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>Zamknij &amp;kartę nośnika wymiennego</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="790"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>Z&amp;mień katalog w karcie na katalog użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="793"/>
        <source>Switch &amp;user command:</source>
        <translation>Polecenie przełączania &amp;użytkownika:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="796"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>Menedżer &amp;archiwów:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="797"/>
        <source>Templates</source>
        <translation>Szablony</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="798"/>
        <source>Show only user defined templates in menu</source>
        <translation>Pokazuj w menu tylko szablony zdefiniowane przez użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="799"/>
        <source>Show only one template for each MIME type</source>
        <translation>Pokazuj tylko jeden szablon dla każdego typu MIME</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="800"/>
        <source>Run default application after creation from template</source>
        <translation>Uruchom domyślną aplikację po utworzeniu pliku z szablonu</translation>
    </message>
    <message>
        <source>Close tab containing removable medium</source>
        <translation type="vanished">Zamknięcie karty</translation>
    </message>
    <message>
        <source>Change folder in the tab to home folder</source>
        <translation type="vanished">Przejście do katalogu użytkownika</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="791"/>
        <source>Programs</source>
        <translation>Programy</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="792"/>
        <source>Terminal emulator:</source>
        <translation>Emulator terminala:</translation>
    </message>
    <message>
        <source>Switch user command:</source>
        <translation type="vanished">Przełączanie użytkowników:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="794"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>Przykład: &quot;xterm -e %s&quot; dla terminala lub &quot;gksu %s&quot; dla przełączania użytkownika.
%s = polecenie, które chcesz wykonać za pomocą terminala lub su.</translation>
    </message>
    <message>
        <source>Archiver integration:</source>
        <translation type="vanished">Menedżer archiwów:</translation>
    </message>
    <message>
        <location filename="../../build/pcmanfm/ui_preferences.h" line="749"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>Używanie dziesiętnych prefiksów SI zamiast binarnych IEC</translation>
    </message>
</context>
</TS>
